@@ -2,21 +2,21 @@ import logging
 import telegram
 from typing import *
 from royalnet.serf.telegram.telegramserf import TelegramSerf, escape
-from royalnet.commands import *
+import royalnet.commands as rc
 
 
 log = logging.getLogger(__name__)
 
 
-class TelegramMessageEvent(Event):
+class TelegramMessageEvent(rc.HeraldEvent):
     name = "telegram_message"
 
     async def run(self, chat_id, text, **kwargs) -> dict:
-        if not self.interface.name == "telegram":
-            raise UnsupportedError()
+        if not isinstance(self.parent, TelegramSerf):
+            raise rc.UnsupportedError()
 
         # noinspection PyTypeChecker
-        serf: TelegramSerf = self.interface.serf
+        serf: TelegramSerf = self.parent
 
         log.debug("Forwarding message from Herald to Telegram.")
         await serf.api_call(serf.client.send_message,
