@@ -1,19 +1,16 @@
 import royalnet.utils as ru
-from royalnet.backpack.tables import *
-from royalnet.constellation.api import *
+import royalnet.constellation.api as rca
 from ..tables import Cvstats
 
 
-class ApiCvstatsLatestStar(ApiStar):
+class ApiCvstatsLatestStar(rca.ApiStar):
     path = "/api/cvstats/latest/v1"
 
-    methods = ["GET"]
-
-    summary = "Get the latest 500 cvstats."
-
     tags = ["cvstats"]
 
-    async def api(self, data: ApiData) -> ru.JSON:
+    @rca.magic
+    async def get(self, data: rca.ApiData) -> ru.JSON:
+        """Get the latest 500 cvstats recorded."""
         CvstatsT = self.alchemy.get(Cvstats)
 
         cvstats = data.session.query(CvstatsT).order_by(CvstatsT.timestamp.desc()).limit(500).all()
